@@ -302,37 +302,37 @@ GERMAN = Translation(
     language_name="German",
     language_code="de",
     translations={
-        "About": "Um",
+        "About": "Über",
         "Add Row": "Zeile hinzufügen",
         "Add": "Hinzufügen",
-        "Apply": "Sich bewerben",
+        "Apply": "Anwenden",
         "Ascending": "Aufsteigend",
         "Back to home page": "Zurück zur Startseite",
-        "Back": "Der Rücken",
+        "Back": "Zurück",
         "Change password": "Passwort ändern",
-        "Clear filters": "Klare Filter",
-        "Close": "Nah dran",
-        "Create": "Schaffen",
+        "Clear filters": "Filter löschen",
+        "Close": "Schließen",
+        "Create": "Anlegen",
         "Current password": "Jetziges Passwort",
         "Dark Mode": "Dunkler Modus",
         "Days": "Tage",
         "Delete": "Löschen",
         "Descending": "Absteigend",
         "Edit": "Bearbeiten",
-        "Export CSV": "Exportieren Sie CSV",
+        "Export CSV": "Exportieren nach CSV",
         "Filter": "Filter",
         "Form submitted": "Formular eingereicht",
-        "Forms": "Formen",
+        "Forms": "Formulare",
         "Go to page": "Gehen Sie zur Seite",
         "Hide Filters": "Filter ausblenden",
         "Hide referencing tables": "Referenzierungstabellen ausblenden",
-        "Home": "Heim",
+        "Home": "Startseite",
         "Hours": "Std",
-        "Light Mode": "Lichtmodus",
+        "Light Mode": "Heller Modus",
         "Loading": "Wird geladen",
         "Log out": "Ausloggen",
         "Login": "Anmeldung",
-        "Minutes": "Protokoll",
+        "Minutes": "Minuten",
         "New password confirmation": "Neues Passwort bestätigen",
         "New password": "Neues Passwort",
         "New value": "Neuer Wert",
@@ -341,25 +341,25 @@ GERMAN = Translation(
         "page": "Seite",
         "Password": "Passwort",
         "result(s)": "Ergebnis(se)",
-        "rows": "Reihen",
+        "rows": "Zeilen",
         "Save": "Speichern",
         "Seconds": "Sekunden",
         "Select a column to update": "Wählen Sie eine Spalte aus, um zu aktualisieren",
         "Select a Column": "Wählen Sie eine Spalte aus",
         "Select a table in the sidebar to get started.": "Wählen Sie eine Tabelle in der Seitenleiste aus, um loszulegen.",
-        "selected result(s) on": "ausgewählte Ergebnisse (en) auf",
+        "selected result(s) on": "ausgewählte(s) Ergebnis(se) auf",
         "Show Filters": "Filter anzeigen",
         "Show referencing tables": "Referenzierungstabellen anzeigen",
         "Showing": "Zeigen",
         "Sort by": "Sortieren nach",
         "Sort": "Sortieren",
-        "Submit": "Einreichen",
+        "Submit": "Abschicken",
         "Tables": "Tabellen",
         "Thanks for using Piccolo Admin.": "Vielen Dank für die Verwendung von Piccolo Admin.",
         "Update": "Aktualisieren",
         "Use again": "Wiederbenutzen",
         "Username": "Nutzername",
-        "Version": "Ausführung",
+        "Version": "Version",
         "Weeks": "Wochen",
         "Welcome to": "Willkommen zu",
         "with a matching": "mit einem Matching",
